@@ -6,6 +6,7 @@ import renderSandboxedMermaid from './render_sandboxed_mermaid';
 import { renderGlql } from './render_glql';
 import { renderJSONTable, renderJSONTableHTML } from './render_json_table';
 import { addAriaLabels } from './accessibility';
+import { renderImageLightbox } from './render_image_lightbox';
 
 function initPopovers(elements) {
   if (!elements.length) return;
@@ -33,6 +34,7 @@ export function renderGFM(element) {
     userEls,
     popoverEls,
     taskListCheckboxEls,
+    imageEls,
   ] = [
     '.js-syntax-highlight',
     '.js-render-kroki[hidden]',
@@ -40,10 +42,12 @@ export function renderGFM(element) {
     '.js-render-mermaid',
     '[data-canonical-lang="json"][data-lang-params~="table"]',
     'table[data-table-fields]',
-    '[data-canonical-lang="glql"]',
+    '[data-canonical-lang="glql"], .language-glql',
     '.gfm-project_member',
     '.gfm-issue, .gfm-work_item, .gfm-merge_request, .gfm-epic, .gfm-milestone',
     '.task-list-item-checkbox',
+    // eslint-disable-next-line @gitlab/require-i18n-strings
+    'a>img',
   ].map((selector) => Array.from(element.querySelectorAll(selector)));
 
   syntaxHighlight(highlightEls);
@@ -55,5 +59,6 @@ export function renderGFM(element) {
   highlightCurrentUser(userEls);
   initPopovers(popoverEls);
   addAriaLabels(taskListCheckboxEls);
-  renderGlql(glqlEls.map((e) => e.parentNode));
+  renderGlql(glqlEls);
+  renderImageLightbox(imageEls, element);
 }
