@@ -1,11 +1,13 @@
 import Vue from 'vue';
-import { createPinia, PiniaVuePlugin } from 'pinia';
+import { createPinia, PiniaVuePlugin, setActivePinia } from 'pinia';
 import { globalAccessorPlugin, syncWithVuex } from '~/pinia/plugins';
 
 Vue.use(PiniaVuePlugin);
 
 const pinia = createPinia();
 
+setActivePinia(pinia);
+
 pinia.use(syncWithVuex);
 pinia.use(globalAccessorPlugin);
 
