@@ -15,6 +15,7 @@ export const portalState = Vue.observable({
 export const sidebarState = Vue.observable({
   isCollapsed: false,
   isMobile: false,
+  isIconOnly: false,
   hasPeeked: false,
   isPeek: false,
   isPeekable: false,
@@ -22,10 +23,20 @@ export const sidebarState = Vue.observable({
   wasHoverPeek: false,
 });
 
+export const CHAT_MODES = {
+  CLASSIC: 'classic',
+  AGENTIC: 'agentic',
+};
+
 export const duoChatGlobalState = Vue.observable({
   commands: [],
   isShown: false,
   isAgenticChatShown: false,
+  chatMode: CHAT_MODES.CLASSIC, // CHAT_MODES.CLASSIC or CHAT_MODES.AGENTIC - single source of truth for chat mode
+  activeTab: null, // For embedded mode: which tab is active in the AI panel ('chat', 'history', etc.)
+  lastRoutePerTab: {}, // Tracks the last visited route for each tab (e.g., { sessions: '/agent-sessions/123' })
+  activeThread: undefined, // Persisted across component recreations when overlay closes/reopens
+  multithreadedView: 'chat', // Persisted view state: 'chat' or 'list'
 });
 
 export const SUPER_SIDEBAR_PEEK_OPEN_DELAY = 200;
