@@ -261,6 +261,7 @@ module ApplicationSettingsHelper
       :after_sign_up_text,
       :akismet_api_key,
       :akismet_enabled,
+      :allow_immediate_namespaces_deletion,
       :allow_local_requests_from_hooks_and_services,
       :allow_local_requests_from_web_hooks_and_services,
       :allow_local_requests_from_system_hooks,
@@ -450,6 +451,7 @@ module ApplicationSettingsHelper
       :spam_check_api_key,
       :terminal_max_session_time,
       :terms,
+      :terraform_state_encryption_enabled,
       :throttle_authenticated_api_enabled,
       :throttle_authenticated_api_period_in_seconds,
       :throttle_authenticated_api_requests_per_period,
@@ -502,6 +504,7 @@ module ApplicationSettingsHelper
       :unique_ips_limit_per_user,
       :unique_ips_limit_time_window,
       :usage_ping_enabled,
+      :usage_ping_generation_enabled,
       :usage_ping_features_enabled,
       :use_clickhouse_for_analytics,
       :user_default_external,
@@ -595,6 +598,7 @@ module ApplicationSettingsHelper
       :project_api_limit,
       :project_invited_groups_api_limit,
       :projects_api_limit,
+      :project_members_api_limit,
       :create_organization_api_limit,
       :user_contributed_projects_api_limit,
       :user_projects_api_limit,
@@ -633,12 +637,17 @@ module ApplicationSettingsHelper
       :minimum_language_server_version,
       :vscode_extension_marketplace,
       :vscode_extension_marketplace_enabled,
+      :vscode_extension_marketplace_extension_host_domain,
       :reindexing_minimum_index_size,
       :reindexing_minimum_relative_bloat_size,
       :anonymous_searches_allowed,
+      :default_search_scope,
       :git_push_pipeline_limit,
       :delay_user_account_self_deletion,
-      :resource_usage_limits
+      :resource_usage_limits,
+      :runner_jobs_request_api_limit,
+      :runner_jobs_patch_trace_api_limit,
+      :runner_jobs_endpoints_api_limit
     ].tap do |settings|
       unless Gitlab.com?
         settings << :deactivate_dormant_users
