@@ -42,6 +42,15 @@ module IconsHelper
     ActionController::Base.helpers.image_path('file_icons/file_icons.svg', host: sprite_base_url)
   end
 
+  def illustrations_path
+    @illustrations_path ||= begin
+      # SVG Sprites currently don't work across domains, so in the case of a CDN
+      # we have to set the current path deliberately to prevent addition of asset_host
+      sprite_base_url = Gitlab.config.gitlab.url if ActionController::Base.asset_host
+      ActionController::Base.helpers.image_path('illustrations.svg', host: sprite_base_url)
+    end
+  end
+
   def sprite_icon(
     icon_name,
     size: DEFAULT_ICON_SIZE,
