@@ -20,8 +20,6 @@ module Ci
 
     self.primary_key = :id
 
-    ignore_column :token, remove_with: '18.5', remove_after: '2025-09-21'
-
     add_authentication_token_field :token,
       encrypted: :required,
       expires_at: :compute_token_expiration,
@@ -154,7 +152,6 @@ module Ci
     scope :created_by_admins, -> { with_creator_id(User.admins.ids) }
 
     scope :with_creator_id, ->(value) { where(creator_id: value) }
-    scope :with_sharding_key, ->(value) { where(sharding_key_id: value) }
 
     scope :belonging_to_group_or_project_descendants, ->(group_id) {
       group_ids = Ci::NamespaceMirror.by_group_and_descendants(group_id).select(:namespace_id)
@@ -226,6 +223,7 @@ module Ci
       exclude_runners = unscoped { project.runners.select(:id) }.to_sql
 
       where(locked: false)
+        .where(organization_id: project.organization_id)
         .where.not("ci_runners.id IN (#{exclude_runners})")
         .project_type
     end
@@ -355,6 +353,10 @@ module Ci
       ::Ci::RunnerTagging
     end
 
+    def self.created_runner_prefix
+      ::Authn::TokenField::PrefixHelper.prepend_instance_prefix(CREATED_RUNNER_TOKEN_PREFIX)
+    end
+
     def runner_matcher
       Gitlab::Ci::Matching::RunnerMatcher.new({
         runner_ids: [id],
@@ -383,11 +385,6 @@ module Ci
 
       begin
         transaction do
-          if projects.id_in(sharding_key_id).empty? && !update_project_id
-            self.errors.add(:assign_to, 'Runner is orphaned and no fallback owner exists')
-            next false
-          end
-
           self.runner_projects << ::Ci::RunnerProject.new(project: project, runner: self)
           self.save!
         end
@@ -449,10 +446,16 @@ module Ci
       return unless token
 
       # We want to show the first characters of the hash, so we need to bypass any fixed components of the token, such
-      # as CREATED_RUNNER_TOKEN_PREFIX, REGISTRATION_RUNNER_TOKEN_PREFIX or legacy_partition_id_prefix_in_16_bit_encode
+      # as instance_prefix, CREATED_RUNNER_TOKEN_PREFIX, REGISTRATION_RUNNER_TOKEN_PREFIX or legacy_partition_id_prefix_in_16_bit_encode
+
       legacy_partition_prefix = legacy_partition_id_prefix_in_16_bit_encode
       start_index = if authenticated_user_registration_type?
-                      CREATED_RUNNER_TOKEN_PREFIX.length
+                      instance_prefix = ::Authn::TokenField::PrefixHelper.instance_prefix
+                      if instance_prefix.present? && token.starts_with?(instance_prefix)
+                        CREATED_RUNNER_TOKEN_PREFIX.length + "#{instance_prefix}-".length
+                      else
+                        CREATED_RUNNER_TOKEN_PREFIX.length
+                      end
                     elsif token.start_with?(REGISTRATION_RUNNER_TOKEN_PREFIX)
                       REGISTRATION_RUNNER_TOKEN_PREFIX.length
                     else
@@ -468,6 +471,10 @@ module Ci
       tag_list.any?
     end
 
+    def tagging_tag_ids
+      taggings.pluck(:tag_id)
+    end
+
     def predefined_variables
       Gitlab::Ci::Variables::Collection.new
         .append(key: 'CI_RUNNER_ID', value: id.to_s)
@@ -550,9 +557,6 @@ module Ci
       RunnerManager.safe_find_or_create_by!(runner_id: id, system_xid: system_xid.to_s) do |m|
         m.runner_type = runner_type
         m.organization_id = organization_id
-
-        # Use a bogus sharding_key_id instead of copying a potentially NULL value from the runner
-        m.sharding_key_id = instance_type? ? nil : (sharding_key_id || -1)
       end
       # rubocop: enable Performance/ActiveRecordSubtransactionMethods
     end
@@ -593,20 +597,6 @@ module Ci
       Project.order(projects_added_to_runner_asc).find_by_id(project_ids)
     end
 
-    # Ensure we have a valid sharding_key_id. Logic is similar to the one used in
-    # Ci::Runners::UpdateProjectRunnersOwnerService when a project is deleted
-    def update_project_id
-      project_id = fallback_owner_project&.id
-
-      return if project_id.nil?
-
-      self.clear_memoization(:owner)
-      self.sharding_key_id = project_id
-
-      runner_managers.where(runner_type: :project_type).each_batch { |batch| batch.update_all(sharding_key_id: project_id) }
-      taggings.where(runner_type: :project_type).update_all(sharding_key_id: project_id)
-    end
-
     def compute_token_expiration_instance
       return unless expiration_interval = Gitlab::CurrentSettings.runner_token_expiration_interval
 
@@ -688,7 +678,7 @@ module Ci
     def prefix_for_new_and_legacy_runner
       return REGISTRATION_RUNNER_TOKEN_PREFIX if registration_token_registration_type?
 
-      CREATED_RUNNER_TOKEN_PREFIX
+      self.class.created_runner_prefix
     end
 
     def memoize_owner
