@@ -9,9 +9,14 @@ module Banzai
   module Filter
     module MarkdownEngines
       class GlfmMarkdown < Base
+        # Table of characters that need this special handling. It consists of
+        # the GitLab special reference characters.
+        REFERENCE_CHARS = %w[$ % # & @ ! ~ ^ :].freeze
+
         OPTIONS = {
           alerts: true,
           autolink: true,
+          cjk_friendly_emphasis: true,
           description_lists: true,
           escaped_char_spans: true,
           footnotes: true,
@@ -22,6 +27,7 @@ module Banzai
           math_code: true,
           math_dollars: true,
           multiline_block_quotes: true,
+          only_escape_chars: REFERENCE_CHARS,
           placeholder_detection: true,
           relaxed_autolinks: true,
           sourcepos: true,
@@ -40,7 +46,8 @@ module Banzai
           autolink: true,
           hardbreaks: false,
           strikethrough: true,
-          unsafe: false
+          unsafe: false,
+          relaxed_autolinks: true
         }.freeze
 
         def render(text)
