@@ -82,6 +82,10 @@ module QA
               )
             end
           end
+
+          return unless Runtime::Env.project_studio_enabled? && !skip_page_validation
+
+          Page::Main::Menu.perform(&:enable_project_studio)
         end
 
         def sign_in_using_admin_credentials
@@ -91,6 +95,7 @@ module QA
           end
 
           Page::Main::Menu.perform(&:has_personal_area?)
+          Page::Main::Menu.perform(&:enable_project_studio) if Runtime::Env.project_studio_enabled?
         end
 
         def sign_in_using_ldap_credentials(user:)
@@ -109,6 +114,8 @@ module QA
           Page::Main::Menu.perform(&:signed_in?)
 
           dismiss_duo_chat_popup if respond_to?(:dismiss_duo_chat_popup)
+
+          Page::Main::Menu.perform(&:enable_project_studio) if Runtime::Env.project_studio_enabled?
         end
 
         def has_sign_in_tab?(wait: Capybara.default_max_wait_time)
