@@ -30,6 +30,10 @@ module QA
           element 'preferences-item'
         end
 
+        view 'app/assets/javascripts/super_sidebar/components/user_menu_project_studio_section.vue' do
+          element 'toggle-project-studio-link'
+        end
+
         view 'app/assets/javascripts/super_sidebar/components/user_menu_profile_item.vue' do
           element 'user-profile-link'
         end
@@ -71,14 +75,17 @@ module QA
         end
 
         def go_to_workspaces
-          # skip_finished_loading_check in case there are workspaces currently being terminated
-          click_element('nav-item-link', submenu_item: 'Workspaces', skip_finished_loading_check: true)
+          click_element('nav-item-link', submenu_item: 'Workspaces')
         end
 
         def go_to_menu_dropdown_option(option_name)
           click_element(option_name)
         end
 
+        def go_to_merge_request_dashboard
+          click_element('merge-requests-shortcut-button')
+        end
+
         def go_to_todos
           click_element('todos-shortcut-button')
         end
@@ -103,6 +110,34 @@ module QA
           click_element 'user-avatar-content' if has_element?('user-profile-link', wait: 0)
         end
 
+        def dismiss_welcome_modal_if_present
+          return unless has_element?('#dap_welcome_modal___BV_modal_footer_', wait: 1)
+
+          click_button 'Get started'
+          within(find('#dap_welcome_modal___BV_modal_content_')) { click_element('close-icon') }
+          wait_until(reload: false) do
+            !has_css?('#dap_welcome_modal___BV_modal_footer_')
+          end
+        end
+
+        def enable_project_studio
+          dismiss_welcome_modal_if_present
+          click_element 'user-avatar-content'
+
+          if find_element('toggle-project-studio-link').find('button[role="switch"]')['aria-checked'] == 'false'
+            QA::Runtime::Logger.info("Enabling Project Studio UI")
+            click_element 'toggle-project-studio-link'
+            dismiss_welcome_modal_if_present
+            expand_sidebar_if_collapsed
+          else
+            QA::Runtime::Logger.info("Project Studio UI already enabled!")
+          end
+
+          # Close user menu
+          click_element 'user-avatar-content' if has_element?('user-profile-link', wait: 0)
+          wait_for_requests
+        end
+
         def not_signed_in?
           return true if Page::Main::Login.perform(&:on_login_page?)
 
@@ -117,6 +152,7 @@ module QA
 
             break true unless signed_in?
 
+            dismiss_welcome_modal_if_present
             within_user_menu do
               click_element 'sign-out-link'
             end
@@ -179,11 +215,9 @@ module QA
         private
 
         def within_user_menu(&block)
-          within_element('super-sidebar') do
-            click_element 'user-avatar-content' unless has_element?('user-profile-link', wait: 1)
+          click_element 'user-avatar-content' unless has_element?('user-profile-link', wait: 1)
 
-            within_element('user-dropdown', &block)
-          end
+          within_element('user-dropdown', &block)
         end
       end
     end
