@@ -10,8 +10,7 @@ module QA
 
           tags "~github", "~external_api_calls", "~skip_live_env", *Specs::Runner::DEFAULT_SKIPPED_TAGS
 
-          pipeline_mappings test_on_omnibus: %w[airgapped],
-            test_on_omnibus_nightly: %w[airgapped]
+          pipeline_mappings test_on_omnibus: %w[airgapped]
 
           def perform(address, *rspec_options)
             Runtime::Scenario.define(:network, 'airgapped')
