@@ -14,14 +14,7 @@ module QA
 
           pipeline_mappings test_on_cng: %w[cng-instance],
             test_on_gdk: %w[gdk-instance gdk-instance-gitaly-transactions gdk-instance-ff-inverse],
-            test_on_omnibus: %w[instance git-sha256-repositories relative-url],
-            test_on_omnibus_nightly: %w[
-              instance-image-slow-network
-              nplus1-instance-image
-              relative-url
-              decomposition-single-db
-              decomposition-multiple-db
-            ]
+            test_on_omnibus: %w[instance git-sha256-repositories relative-url]
         end
       end
     end
