@@ -7,9 +7,7 @@ module QA
         class Registry < Test::Instance::All
           tags :registry
 
-          pipeline_mappings test_on_cng: %w[cng-registry],
-            test_on_omnibus: %w[registry],
-            test_on_omnibus_nightly: %w[registry-with-cdn]
+          pipeline_mappings test_on_cng: %w[cng-registry], test_on_omnibus: %w[registry]
         end
       end
     end
