@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 module QA
-  RSpec.describe 'Plan', :smoke, product_group: :project_management do
+  RSpec.describe 'Plan', :smoke, feature_category: :team_planning do
     describe 'filter issue comments activities' do
       before do
         Flow::Login.sign_in
@@ -11,9 +11,16 @@ module QA
 
       it(
         'filters comments and activities in an issue', :aggregate_failures,
-        testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347948'
+        testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347948',
+        quarantine: {
+          issue: 'https://gitlab.com/gitlab-org/gitlab/-/issues/534698',
+          type: :flaky
+        }
       ) do
-        Page::Project::Issue::Show.perform do |show|
+        work_item_enabled = Page::Project::Issue::Show.perform(&:work_item_enabled?)
+        page_type = work_item_enabled ? Page::Project::WorkItem::Show : Page::Project::Issue::Show
+
+        page_type.perform do |show|
           my_own_comment = "My own comment"
           made_the_issue_confidential = "made the issue confidential"
 
