@@ -26,6 +26,8 @@ RSpec.shared_context "with diff file component tests" do
     render_component
     diff_path = "/#{namespace.to_param}/#{project.to_param}/-/blob/#{diff_file.content_sha}/#{diff_file.file_path}"
     expect(file_data['diff_lines_path']).to eq("#{diff_path}/diff_lines")
+    expect(file_data['old_path']).to eq(diff_file.old_path)
+    expect(file_data['new_path']).to eq(diff_file.new_path)
   end
 
   it "enables virtual rendering" do
@@ -50,7 +52,6 @@ RSpec.shared_context "with diff file component tests" do
         expect(file_data['viewer']).to eq('no_preview')
         expect(web_component).to have_css("[data-virtual='no_preview']")
         expect(web_component).to have_css("[style*='--virtual-paragraphs-count: 2']")
-        expect(web_component).to have_css("[style*='--virtual-action-buttons-present: 1']")
       end
     end
 
@@ -100,7 +101,6 @@ RSpec.shared_context "with diff file component tests" do
       expect(file_data['viewer']).to eq('no_preview')
       expect(web_component).to have_css("[data-virtual='no_preview']")
       expect(web_component).to have_css("[style*='--virtual-paragraphs-count: 2']")
-      expect(web_component).to have_css("[style*='--virtual-action-buttons-present: 1']")
     end
   end
 
