@@ -484,20 +484,16 @@ RSpec.describe Projects::CompareController, feature_category: :source_code_manag
     end
 
     context 'with commit count threshold' do
-      let(:from_project_id) { nil }
-      let(:from_ref) { '6f6d7e7ed97bb5f0054f2b1df789b39ca89b6ff9' }
-      let(:to_ref) { '5937ac0a7beb003549fc5fd26fc247adbce4a52e' }
-      let(:straight) { "false" }
+      let_it_be(:from_project_id) { nil }
+      let_it_be(:from_ref) { '6f6d7e7ed97bb5f0054f2b1df789b39ca89b6ff9' }
+      let_it_be(:to_ref) { '5937ac0a7beb003549fc5fd26fc247adbce4a52e' }
+      let_it_be(:straight) { "false" }
 
-      before do
+      before_all do
         create(:ci_pipeline, project: project, ref: to_ref)
       end
 
       context 'when commits count is below safe size limit' do
-        before do
-          stub_const('MergeRequestDiff::COMMITS_SAFE_SIZE', 100)
-        end
-
         it 'loads pipeline information for commits' do
           expect_next_instance_of(CommitCollection) do |instance|
             expect(instance).to receive(:with_latest_pipeline).with(to_ref).and_call_original
