@@ -29,30 +29,6 @@ RSpec.describe '.gitlab/ci/rules.gitlab-ci.yml', :unlimited_max_formatted_output
     end
   end
 
-  describe '.review:rules:start-review-app-pipeline' do
-    let(:base_rules) { config.dig('.review:rules:start-review-app-pipeline', 'rules') }
-
-    context 'with .review:rules:review-stop' do
-      let(:derived_rules) { config.dig('.review:rules:review-stop', 'rules') }
-
-      it 'has the same rules as the base, but automatic jobs changed to manual' do
-        base_rules.zip(derived_rules).each do |(base, derived)|
-          # .review:rules:review-stop don't set variables
-          base.delete('variables')
-          base_with_manual_and_allowed_to_fail =
-            # base can be an array when we're using !reference
-            if base.is_a?(Array) || base['when'] == 'never'
-              base
-            else
-              base.merge('when' => 'manual', 'allow_failure' => true)
-            end
-
-          expect(derived).to eq(base_with_manual_and_allowed_to_fail)
-        end
-      end
-    end
-  end
-
   shared_examples 'predictive is inverse of non-predictive' do
     context 'with derived rules' do
       it 'has the "when: never" in reverse compared to the base' do
@@ -157,7 +133,7 @@ RSpec.describe '.gitlab/ci/rules.gitlab-ci.yml', :unlimited_max_formatted_output
         '.gitlab_kas_secret',
         '.gitlab_shell_secret',
         '.gitlab_workhorse_secret',
-        '.gitlab/agents/review-apps/config.yaml',
+        '.gitlab_suggested_reviewers_secret',
         '.gitlab/changelog_config.yml',
         '.gitlab/CODEOWNERS',
         '.gitlab/lint/unused_methods/excluded_methods.yml',
@@ -175,6 +151,9 @@ RSpec.describe '.gitlab/ci/rules.gitlab-ci.yml', :unlimited_max_formatted_output
         '.test_license_encryption_key.pub',
         '.vale.ini',
         '.vscode/extensions.json',
+        '.vscode/tasks.json',
+        'ee/frontend_islands/apps/duo_next/.vscode/extensions.json',
+        'ee/frontend_islands/apps/duo_next/.prettierignore',
         'ee/lib/ee/gitlab/background_migration/.rubocop.yml',
         'ee/LICENSE',
         'gems/error_tracking_open_api/.openapi-generator/FILES',
@@ -191,6 +170,7 @@ RSpec.describe '.gitlab/ci/rules.gitlab-ci.yml', :unlimited_max_formatted_output
         'storybook/.babelrc.json',
         'yarn-error.log'
       ] +
+      Dir.glob('.claude/**/*') +
       Dir.glob('.bundle/**/*') +
       Dir.glob('.github/*') +
       Dir.glob('.gitlab/duo/**/*') +
@@ -203,9 +183,11 @@ RSpec.describe '.gitlab/ci/rules.gitlab-ci.yml', :unlimited_max_formatted_output
       Dir.glob('{metrics_server,sidekiq_cluster}/*') +
       Dir.glob('{{,ee/}spec/fixtures,tmp}/**/*', File::FNM_DOTMATCH) +
       Dir.glob('*.md') +
+      Dir.glob('ee/frontend_islands/**/*.md') +
+      Dir.glob('public/assets/vite/.vite/**/*') +
       Dir.glob('changelogs/*') +
       Dir.glob('doc/.{markdownlint,vale}/**/*', File::FNM_DOTMATCH) +
-      Dir.glob('node_modules/**/*', File::FNM_DOTMATCH) +
+      Dir.glob('**/node_modules/**/*', File::FNM_DOTMATCH) +
       Dir.glob('patches/*') +
       Dir.glob('public/assets/**/.*') +
       Dir.glob('qa/{,**/}.*') +
@@ -222,7 +204,10 @@ RSpec.describe '.gitlab/ci/rules.gitlab-ci.yml', :unlimited_max_formatted_output
       ] +
       Dir.glob('{auto_explain,crystalball,knapsack,rspec}/**/*') +
       Dir.glob('coverage/**/*', File::FNM_DOTMATCH) +
-      Dir.glob('vendor/ruby/**/*', File::FNM_DOTMATCH)
+      Dir.glob('coverage-frontend/**/*', File::FNM_DOTMATCH) +
+      Dir.glob('ee/frontend_islands/apps/**/coverage/**/*', File::FNM_DOTMATCH) +
+      Dir.glob('vendor/ruby/**/*', File::FNM_DOTMATCH) +
+      Dir.glob('builds/**/*', File::FNM_DOTMATCH)
     ).freeze
     all_files = Dir.glob('{,**/}*', File::FNM_DOTMATCH) -
       no_matching_needed_files -
@@ -281,7 +266,8 @@ RSpec.describe '.gitlab/ci/rules.gitlab-ci.yml', :unlimited_max_formatted_output
         all_matching_files.merge(files)
       end
 
-      it 'does not miss files to match' do
+      it 'does not miss files to match',
+        quarantine: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/11473' do
         expect(all_files - all_matching_files.to_a).to be_empty
       end
     end
