@@ -246,10 +246,6 @@ FactoryBot.define do
     trait :aimed_for_deletion do
       marked_for_deletion_at { Date.yesterday }
       deleting_user { creator }
-
-      after(:create) do |project|
-        create(:namespace_deletion_schedule, namespace: project.project_namespace)
-      end
     end
 
     trait :not_aimed_for_deletion do
@@ -675,6 +671,10 @@ FactoryBot.define do
     end
   end
 
+  trait :in_user_namespace do
+    namespace { association :user_namespace }
+  end
+
   trait :in_group do
     namespace { association :group, organization: organization }
   end
@@ -703,11 +703,4 @@ FactoryBot.define do
       project.import_data.merge_data({ user_contribution_mapping_enabled: true })
     end
   end
-
-  trait :user_mapping_to_personal_namespace_owner_enabled do
-    after(:build) do |project|
-      project.import_data ||= project.build_import_data
-      project.import_data.merge_data({ user_mapping_to_personal_namespace_owner_enabled: true })
-    end
-  end
 end
