@@ -18,6 +18,7 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
 
       project.add_developer(user)
       project.update!(auto_devops_attributes: { enabled: false })
+      stub_feature_flags(pipelines_page_graphql: false)
     end
 
     describe 'GET /:project/-/pipelines' do
@@ -229,7 +230,7 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
 
         shared_examples_for 'detached merge request pipeline' do
           it 'shows pipeline information without pipeline ref', :sidekiq_might_not_need_inline do
-            within '.pipeline-tags' do
+            within_testid('pipeline-url-table-cell') do
               expect(page).to have_content(expected_detached_mr_tag)
 
               expect(page).to have_link(merge_request.iid.to_s, href: project_merge_request_path(project, merge_request))
@@ -269,7 +270,7 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
 
         shared_examples_for 'Correct merge request pipeline information' do
           it 'does not show detached tag for the pipeline, and shows the link of the merge request, and does not show the ref of the pipeline', :sidekiq_might_not_need_inline do
-            within '.pipeline-tags' do
+            within_testid('pipeline-url-table-cell') do
               expect(page).not_to have_content(expected_detached_mr_tag)
 
               expect(page).to have_link(merge_request.iid.to_s, href: project_merge_request_path(project, merge_request))
@@ -961,7 +962,9 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
 
   context 'when user is not logged in' do
     before do
+      stub_feature_flags(pipelines_page_graphql: false)
       project.update!(auto_devops_attributes: { enabled: false })
+
       visit project_pipelines_path(project)
     end
 
@@ -977,7 +980,7 @@ RSpec.describe 'Pipelines', :js, feature_category: :continuous_integration do
       let(:project) { create(:project, :private, :repository) }
 
       it 'redirects the user to sign_in and displays the flash alert' do
-        expect(page).to have_content 'You need to sign in'
+        expect(page).to have_content 'Sign in or sign up before continuing'
         expect(page).to have_current_path("/users/sign_in")
       end
     end
