@@ -26,12 +26,14 @@ describe('Linked pipeline', () => {
     type: DOWNSTREAM,
     expanded: false,
     isLoading: false,
+    userPermissions: { updatePipeline: true },
   };
 
   const upstreamProps = {
     ...downstreamProps,
     columnTitle: 'Upstream',
     type: UPSTREAM,
+    userPermissions: { updatePipeline: false },
   };
 
   const findButton = () => wrapper.findComponent(GlButton);
@@ -76,6 +78,7 @@ describe('Linked pipeline', () => {
       type: DOWNSTREAM,
       expanded: false,
       isLoading: false,
+      userPermissions: { updatePipeline: true },
     };
 
     beforeEach(() => {
@@ -150,7 +153,7 @@ describe('Linked pipeline', () => {
         expect(findPipelineLink().attributes('href')).toBe(downstreamProps.pipeline.path);
       });
 
-      it('applies the flex-row css class to the card', () => {
+      it('applies the !gl-flex-row css class to the card', () => {
         expect(findLinkedPipeline().classes()).toContain('gl-flex-row');
         expect(findLinkedPipeline().classes()).not.toContain('gl-flex-row-reverse');
       });
@@ -361,11 +364,11 @@ describe('Linked pipeline', () => {
         beforeEach(() => {
           const pipelineWithTwoActions = {
             ...downstreamProps,
+            userPermissions: { updatePipeline: false },
             pipeline: {
               ...mockPipeline,
               cancelable: true,
               retryable: true,
-              userPermissions: { updatePipeline: false },
             },
           };
 
@@ -432,6 +435,7 @@ describe('Linked pipeline', () => {
       type: DOWNSTREAM,
       expanded: false,
       isLoading: true,
+      userPermissions: { updatePipeline: true },
     };
 
     beforeEach(() => {
@@ -450,6 +454,7 @@ describe('Linked pipeline', () => {
       type: DOWNSTREAM,
       expanded: false,
       isLoading: false,
+      userPermissions: { updatePipeline: true },
     };
 
     beforeEach(() => {
