@@ -3,14 +3,15 @@ import Vue, { nextTick } from 'vue';
 
 import VueApollo, { ApolloMutation } from 'vue-apollo';
 import VueRouter from 'vue-router';
-import { GlBreakpointInstance as breakpointInstance } from '@gitlab/ui/src/utils';
 import VueDraggable from 'vuedraggable';
 import createMockApollo from 'helpers/mock_apollo_helper';
+import { describeSkipVue3, SkipReason } from 'helpers/vue3_conditional';
 import waitForPromises from 'helpers/wait_for_promises';
 import { mockTracking, unmockTracking } from 'helpers/tracking_helper';
 import { shallowMountExtended } from 'helpers/vue_test_utils_helper';
 import permissionsQuery from 'shared_queries/design_management/design_permissions.query.graphql';
 import getDesignListQuery from 'shared_queries/design_management/get_design_list.query.graphql';
+import { PanelBreakpointInstance } from '~/panel_breakpoint_instance';
 import DeleteButton from '~/design_management/components/delete_button.vue';
 import DesignDestroyer from '~/design_management/components/design_destroyer.vue';
 import Design from '~/design_management/components/list/item.vue';
@@ -94,7 +95,13 @@ const designToMove = {
   imageV432x230: 'image-2',
 };
 
-describe('Design management index page', () => {
+const skipReason = new SkipReason({
+  name: 'Design management index page',
+  reason: 'Feature is deprecated',
+  issue: 'https://gitlab.com/groups/gitlab-org/-/epics/18652',
+});
+
+describeSkipVue3(skipReason, () => {
   const registerPath = '/users/sign_up?redirect_to_referer=yes';
   const signInPath = '/users/sign_in?redirect_to_referer=yes';
   let mutate;
@@ -240,8 +247,8 @@ describe('Design management index page', () => {
       createComponent({ designs: mockDesigns, allVersions: [mockVersion] });
       expect(findDropzoneWrapper().classes()).toEqual([
         'gl-flex-col',
-        'col-md-6',
-        'col-lg-3',
+        'gl-col-md-6',
+        'gl-col-lg-3',
         'gl-mt-5',
       ]);
     });
@@ -262,7 +269,7 @@ describe('Design management index page', () => {
     });
 
     it('has correct classes applied to dropzone wrapper', () => {
-      expect(findDropzoneWrapper().classes()).toEqual(['col-12']);
+      expect(findDropzoneWrapper().classes()).toEqual(['gl-col-12']);
     });
 
     it('does not render a toolbar with buttons', async () => {
@@ -786,7 +793,7 @@ describe('Design management index page', () => {
     `(
       'sets draggable disabled value to $reorderDisabled when breakpoint is $breakpoint',
       async ({ breakpoint, reorderDisabled }) => {
-        jest.spyOn(breakpointInstance, 'getBreakpointSize').mockReturnValue(breakpoint);
+        jest.spyOn(PanelBreakpointInstance, 'getBreakpointSize').mockReturnValue(breakpoint);
 
         createComponentWithApollo({});
         await waitForPromises();
