@@ -56,7 +56,7 @@ describe('DiffsStoreMutations', () => {
     it('should set diffFiles in state', () => {
       store[types.SET_DIFF_FILES](['file', 'another file']);
 
-      expect(store.diffFiles.length).toEqual(2);
+      expect(store.diffFiles).toHaveLength(2);
     });
   });
 
@@ -297,7 +297,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode,
       });
 
-      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions.length).toEqual(1);
+      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions).toHaveLength(1);
       expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions[0].id).toEqual(1);
     });
 
@@ -344,7 +344,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode,
       });
 
-      expect(store.diffFiles[0].discussions.length).toEqual(1);
+      expect(store.diffFiles[0].discussions).toHaveLength(1);
       expect(store.diffFiles[0].discussions[0].id).toEqual(1);
     });
 
@@ -394,7 +394,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode,
       });
 
-      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions.length).toEqual(1);
+      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions).toHaveLength(1);
       expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions[0].id).toEqual(1);
 
       store[types.SET_LINE_DISCUSSIONS_FOR_FILE]({
@@ -402,7 +402,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode,
       });
 
-      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions.length).toEqual(1);
+      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions).toHaveLength(1);
       expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions[0].id).toEqual(1);
     });
 
@@ -452,7 +452,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode,
       });
 
-      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions.length).toEqual(1);
+      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions).toHaveLength(1);
       expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions[0].id).toEqual(1);
 
       store[types.SET_LINE_DISCUSSIONS_FOR_FILE]({
@@ -464,7 +464,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode,
       });
 
-      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions[0].notes.length).toBe(1);
+      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions[0].notes).toHaveLength(1);
       expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions[0].resolved).toBe(true);
     });
 
@@ -530,7 +530,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode,
       });
 
-      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions.length).toBe(1);
+      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions).toHaveLength(1);
     });
 
     it('should add legacy discussions to the given line', () => {
@@ -578,7 +578,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode,
       });
 
-      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions.length).toEqual(1);
+      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions).toHaveLength(1);
       expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions[0].id).toEqual(1);
     });
 
@@ -660,7 +660,7 @@ describe('DiffsStoreMutations', () => {
         diffPositionByLineCode: null,
       });
 
-      expect(store.diffFiles[0].discussions.length).toEqual(1);
+      expect(store.diffFiles[0].discussions).toHaveLength(1);
     });
 
     describe('expanded state', () => {
@@ -916,7 +916,7 @@ describe('DiffsStoreMutations', () => {
         lineCode: 'ABC_1',
       });
 
-      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions.length).toEqual(0);
+      expect(store.diffFiles[0][INLINE_DIFF_LINES_KEY][0].discussions).toHaveLength(0);
     });
   });
 
@@ -1312,7 +1312,7 @@ describe('DiffsStoreMutations', () => {
 
       store[types.ADD_DRAFT_TO_FILE]({ filePath: 'path', draft: 'test' });
 
-      expect(store.diffFiles[0].drafts.length).toEqual(1);
+      expect(store.diffFiles[0].drafts).toHaveLength(1);
       expect(store.diffFiles[0].drafts[0]).toEqual('test');
     });
   });
