@@ -14,6 +14,7 @@ import Vuex from 'vuex';
 import stubChildren from 'helpers/stub_children';
 import waitForPromises from 'helpers/wait_for_promises';
 import { useMockInternalEventsTracking } from 'helpers/tracking_internal_events_helper';
+import { scrollTo } from '~/lib/utils/scroll_utils';
 import ErrorTrackingActions from '~/error_tracking/components/error_tracking_actions.vue';
 import ErrorTrackingList from '~/error_tracking/components/error_tracking_list.vue';
 import TimelineChart from '~/error_tracking/components/timeline_chart.vue';
@@ -22,6 +23,8 @@ import errorsList from './list_mock.json';
 
 Vue.use(Vuex);
 
+jest.mock('~/lib/utils/scroll_utils');
+
 describe('ErrorTrackingList', () => {
   let store;
   let wrapper;
@@ -537,9 +540,8 @@ describe('ErrorTrackingList', () => {
         });
 
         it('fetches the next page of results', () => {
-          window.scrollTo = jest.fn();
           findPagination().vm.$emit('input', 2);
-          expect(window.scrollTo).toHaveBeenCalledWith(0, 0);
+          expect(scrollTo).toHaveBeenCalledWith({ top: 0, left: 0 }, wrapper.element);
           expect(actions.fetchPaginatedResults).toHaveBeenCalled();
           expect(actions.fetchPaginatedResults).toHaveBeenLastCalledWith(
             expect.anything(),
