@@ -81,6 +81,8 @@ describe('ide/init_gitlab_web_ide', () => {
     el.dataset.userPreferencesPath = TEST_USER_PREFERENCES_PATH;
     el.dataset.mergeRequest = TEST_MR_ID;
     el.dataset.filePath = TEST_FILE_PATH;
+    el.dataset.extensionHostDomain = 'web-ide.example.net';
+    el.dataset.extensionHostDomainChanged = true;
     el.dataset.editorFont = JSON.stringify({
       fallback_font_family: 'monospace',
       font_faces: [
@@ -106,7 +108,6 @@ describe('ide/init_gitlab_web_ide', () => {
 
   beforeEach(() => {
     gon.current_username = TEST_USERNAME;
-    gon.features = { webIdeLanguageServer: true };
     process.env.GITLAB_WEB_IDE_PUBLIC_PATH = TEST_GITLAB_WEB_IDE_PUBLIC_PATH;
     ideContainer = {
       element: document.createElement('div'),
@@ -157,7 +158,7 @@ describe('ide/init_gitlab_web_ide', () => {
           signIn: TEST_SIGN_IN_PATH,
         },
         featureFlags: {
-          languageServerWebIDE: gon.features.webIdeLanguageServer,
+          languageServerWebIDE: true,
           additionalSourceControlOperations: true,
         },
         editorFont: {
@@ -181,6 +182,17 @@ describe('ide/init_gitlab_web_ide', () => {
       });
     });
 
+    it('provides extensionHostDomain and extensionHostDomainChanged external parameters to workbench URL builder', () => {
+      const rootEl = findRootElement();
+
+      expect(rootEl.dataset.extensionHostDomain).toBe('web-ide.example.net');
+      expect(rootEl.dataset.extensionHostDomainChanged).toBe('true');
+      expect(getWebIDEWorkbenchConfig).toHaveBeenCalledWith({
+        extensionHostDomain: 'web-ide.example.net',
+        extensionHostDomainChanged: true,
+      });
+    });
+
     describe('when web-ide is ready', () => {
       beforeEach(() => {
         start.mockResolvedValue({ ready: Promise.resolve() });
