@@ -32,7 +32,7 @@ import {
 } from '~/lib/utils/http_status';
 import {
   displaySuccessfulInvitationAlert,
-  reloadOnInvitationSuccess,
+  reloadOnMemberInvitationSuccess,
 } from '~/invite_members/utils/trigger_successful_invite_alert';
 import { captureException } from '~/ci/runner/sentry_utils';
 import { helpPagePath } from '~/helpers/help_page_helper';
@@ -203,6 +203,14 @@ describe('InviteMembersModal', () => {
         );
       });
     });
+
+    describe('hasErrorDuringInvite prop', () => {
+      it('does not pass hasErrorDuringInvite prop when function returns null', () => {
+        createInviteMembersToProjectWrapper();
+
+        expect(findBase().props('hasErrorDuringInvite')).toBeUndefined();
+      });
+    });
   });
 
   describe('rendering with tracking considerations', () => {
@@ -394,8 +402,8 @@ describe('InviteMembersModal', () => {
           expect(displaySuccessfulInvitationAlert).toHaveBeenCalled();
         });
 
-        it('calls reloadOnInvitationSuccess', () => {
-          expect(reloadOnInvitationSuccess).toHaveBeenCalled();
+        it('calls reloadOnMemberInvitationSuccess', () => {
+          expect(reloadOnMemberInvitationSuccess).toHaveBeenCalled();
         });
 
         it('does not show the toast message', () => {
@@ -428,8 +436,8 @@ describe('InviteMembersModal', () => {
             expect(displaySuccessfulInvitationAlert).not.toHaveBeenCalled();
           });
 
-          it('does not call reloadOnInvitationSuccess', () => {
-            expect(reloadOnInvitationSuccess).not.toHaveBeenCalled();
+          it('does not call reloadOnMemberInvitationSuccess', () => {
+            expect(reloadOnMemberInvitationSuccess).not.toHaveBeenCalled();
           });
         });
       });
@@ -584,8 +592,8 @@ describe('InviteMembersModal', () => {
             expect(displaySuccessfulInvitationAlert).not.toHaveBeenCalled();
           });
 
-          it('does not call reloadOnInvitationSuccess', () => {
-            expect(reloadOnInvitationSuccess).not.toHaveBeenCalled();
+          it('does not call reloadOnMemberInvitationSuccess', () => {
+            expect(reloadOnMemberInvitationSuccess).not.toHaveBeenCalled();
           });
         });
       });
@@ -703,8 +711,8 @@ describe('InviteMembersModal', () => {
             expect(displaySuccessfulInvitationAlert).not.toHaveBeenCalled();
           });
 
-          it('does not call reloadOnInvitationSuccess', () => {
-            expect(reloadOnInvitationSuccess).not.toHaveBeenCalled();
+          it('does not call reloadOnMemberInvitationSuccess', () => {
+            expect(reloadOnMemberInvitationSuccess).not.toHaveBeenCalled();
           });
         });
       });
@@ -834,8 +842,8 @@ describe('InviteMembersModal', () => {
             expect(displaySuccessfulInvitationAlert).not.toHaveBeenCalled();
           });
 
-          it('does not call reloadOnInvitationSuccess', () => {
-            expect(reloadOnInvitationSuccess).not.toHaveBeenCalled();
+          it('does not call reloadOnMemberInvitationSuccess', () => {
+            expect(reloadOnMemberInvitationSuccess).not.toHaveBeenCalled();
           });
 
           it('tracks successful invite when source is known', () => {
