@@ -44,9 +44,11 @@ import {
   nYearsBefore,
   removeTime,
   secondsToDays,
+  secondsToMinutes,
   secondsToMilliseconds,
   totalDaysInMonth,
   daysToSeconds,
+  millisecondsToSeconds,
 } from '~/lib/utils/datetime/date_calculation_utility';
 import { useFakeDate } from 'helpers/fake_date';
 
@@ -272,7 +274,7 @@ describe('getSundays', () => {
     const dateOfSundays = [3, 10, 17, 24, 31];
     const sundays = getSundays(new Date(2017, 11, 1));
 
-    expect(sundays.length).toBe(5);
+    expect(sundays).toHaveLength(5);
     sundays.forEach((sunday, index) => {
       expect(sunday.getDate()).toBe(dateOfSundays[index]);
     });
@@ -291,7 +293,7 @@ describe('getTimeframeWindowFrom', () => {
     ];
     const timeframe = getTimeframeWindowFrom(startDate, 5);
 
-    expect(timeframe.length).toBe(5);
+    expect(timeframe).toHaveLength(5);
     timeframe.forEach((timeframeItem, index) => {
       expect(timeframeItem.getFullYear()).toBe(mockTimeframe[index].getFullYear());
       expect(timeframeItem.getMonth()).toBe(mockTimeframe[index].getMonth());
@@ -310,7 +312,7 @@ describe('getTimeframeWindowFrom', () => {
     ];
     const timeframe = getTimeframeWindowFrom(startDate, -5);
 
-    expect(timeframe.length).toBe(5);
+    expect(timeframe).toHaveLength(5);
     timeframe.forEach((timeframeItem, index) => {
       expect(timeframeItem.getFullYear()).toBe(mockTimeframe[index].getFullYear());
       expect(timeframeItem.getMonth()).toBe(mockTimeframe[index].getMonth());
@@ -422,7 +424,7 @@ describe('getDatesInRange', () => {
 
     const range = getDatesInRange(d1, d2);
 
-    expect(range.length).toEqual(31);
+    expect(range).toHaveLength(31);
   });
 
   it('applies mapper function if provided fro each item in range', () => {
@@ -438,6 +440,14 @@ describe('getDatesInRange', () => {
   });
 });
 
+describe('secondsToMinutes', () => {
+  it('converts seconds to milliseconds correctly', () => {
+    expect(secondsToMinutes(0)).toBe(0);
+    expect(secondsToMinutes(60)).toBe(1);
+    expect(secondsToMinutes(123)).toBe(2.05);
+  });
+});
+
 describe('secondsToMilliseconds', () => {
   it('converts seconds to milliseconds correctly', () => {
     expect(secondsToMilliseconds(0)).toBe(0);
@@ -446,6 +456,14 @@ describe('secondsToMilliseconds', () => {
   });
 });
 
+describe('millisecondsToSeconds', () => {
+  it('converts milliseconds to seconds correctly', () => {
+    expect(millisecondsToSeconds(0)).toBe(0);
+    expect(millisecondsToSeconds(60000)).toBe(60);
+    expect(millisecondsToSeconds(123000)).toBe(123);
+  });
+});
+
 describe('secondsToDays', () => {
   it('converts seconds to days correctly', () => {
     expect(secondsToDays(0)).toBe(0);
