@@ -2,7 +2,7 @@ import { mount } from '@vue/test-utils';
 import { nextTick } from 'vue';
 import originalOneReleaseQueryResponse from 'test_fixtures/graphql/releases/graphql/queries/one_release.query.graphql.json';
 import { convertOneReleaseGraphQLResponse } from '~/releases/util';
-import * as commonUtils from '~/lib/utils/common_utils';
+import { scrollToElement } from '~/lib/utils/scroll_utils';
 import * as urlUtility from '~/lib/utils/url_utility';
 import EvidenceBlock from '~/releases/components/evidence_block.vue';
 import ReleaseBlockDeployments from '~/releases/components/release_block_deployments.vue';
@@ -14,6 +14,7 @@ import { renderGFM } from '~/behaviors/markdown/render_gfm';
 import { mockDeployment } from '../mock_data';
 
 jest.mock('~/behaviors/markdown/render_gfm');
+jest.mock('~/lib/utils/scroll_utils');
 
 describe('Release block', () => {
   let wrapper;
@@ -165,7 +166,6 @@ describe('Release block', () => {
     let locationHash;
 
     beforeEach(() => {
-      commonUtils.scrollToElement = jest.fn();
       urlUtility.getLocationHash = jest.fn().mockImplementation(() => locationHash);
     });
 
@@ -174,23 +174,23 @@ describe('Release block', () => {
     it('does not attempt to scroll the page if no anchor tag is included in the URL', () => {
       locationHash = '';
       return factory(release).then(() => {
-        expect(commonUtils.scrollToElement).not.toHaveBeenCalled();
+        expect(scrollToElement).not.toHaveBeenCalled();
       });
     });
 
     it("does not attempt to scroll the page if the anchor tag doesn't match the release's tag name", () => {
       locationHash = 'v0.4';
       return factory(release).then(() => {
-        expect(commonUtils.scrollToElement).not.toHaveBeenCalled();
+        expect(scrollToElement).not.toHaveBeenCalled();
       });
     });
 
     it("attempts to scroll itself into view if the anchor tag matches the release's tag name", () => {
       locationHash = release.tagName;
       return factory(release).then(() => {
-        expect(commonUtils.scrollToElement).toHaveBeenCalledTimes(1);
+        expect(scrollToElement).toHaveBeenCalledTimes(1);
 
-        expect(commonUtils.scrollToElement).toHaveBeenCalledWith(wrapper.element);
+        expect(scrollToElement).toHaveBeenCalledWith(wrapper.element);
       });
     });
 
