@@ -16,9 +16,10 @@ import {
   prepareSearchAggregations,
   addCountOverLimit,
   injectRegexSearch,
+  injectUsersScope,
   scopeCrawler,
-  skipBlobESCount,
   buildDocumentTitle,
+  modifySearchQuery,
 } from '~/search/store/utils';
 import { useMockLocationHelper } from 'helpers/mock_window_location_helper';
 import { TEST_HOST } from 'helpers/test_constants';
@@ -316,54 +317,19 @@ describe('Global Search Store Utils', () => {
     });
   });
 
-  describe('injectRegexSearch', () => {
-    describe.each`
-      urlIn                                                            | urlOut
-      ${`${TEST_HOST}/search?search=test&group_id=123`}                | ${'/search?search=test&group_id=123'}
-      ${'/search?search=test&group_id=123'}                            | ${'/search?search=test&group_id=123'}
-      ${`${TEST_HOST}/search?search=test&project_id=123`}              | ${'/search?search=test&project_id=123'}
-      ${'/search?search=test&project_id=123'}                          | ${'/search?search=test&project_id=123'}
-      ${`${TEST_HOST}/search?search=test&project_id=123&group_id=123`} | ${'/search?search=test&project_id=123&group_id=123'}
-      ${'/search?search=test&project_id=123&group_id=123'}             | ${'/search?search=test&project_id=123&group_id=123'}
-    `('modifies urls and links', ({ urlIn, urlOut }) => {
-      it(`should add regex=true to ${urlIn}`, () => {
-        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(true));
-        expect(injectRegexSearch(urlIn)).toEqual(`${urlOut}&regex=true`);
-      });
-
-      it(`should NOT add regex=true to ${urlIn}`, () => {
-        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(false));
-        expect(injectRegexSearch(urlIn)).toEqual(urlOut);
-      });
-    });
-
-    describe.each`
-      urlIn                                | urlOut
-      ${'/search?search=test'}             | ${'/search?search=test'}
-      ${`${TEST_HOST}/search?search=test`} | ${'/search?search=test'}
-      ${'/'}                               | ${'/'}
-    `('does not modify urls and links', ({ urlIn, urlOut }) => {
-      it('should return link with regex equals true', () => {
-        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(true));
-        expect(injectRegexSearch(urlIn)).toEqual(urlOut);
-      });
-    });
-
-    describe.each`
-      urlIn                                                           | urlOut
-      ${'/search?search=test&group_id=123&regex=true'}                | ${'/search?search=test&group_id=123&regex=true'}
-      ${'/search?search=test&project_id=123&regex=true'}              | ${'/search?search=test&project_id=123&regex=true'}
-      ${'/search?search=test&project_id=123&group_id=123&regex=true'} | ${'/search?search=test&project_id=123&group_id=123&regex=true'}
-    `('does not double params', ({ urlIn, urlOut }) => {
-      it(`should not add additional regex=true to ${urlIn} if enabled`, () => {
-        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(true));
-        expect(injectRegexSearch(urlIn)).toEqual(`${urlOut}`);
-      });
-
-      it(`should NOT remove regex=true from ${urlIn} if disabled`, () => {
-        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(false));
-        expect(injectRegexSearch(urlIn)).toEqual(urlOut);
-      });
+  describe('injectUsersScope', () => {
+    useMockLocationHelper();
+    it.each([
+      ['/search', `/search?scope=users`],
+      ['/search?search=test', `/search?search=test&scope=users`],
+      ['/search?search=test&scope=users', `/search?search=test&scope=users`],
+      ['/search?search=test&group_id=123', `/search?search=test&group_id=123&scope=users`],
+      ['/search?search=test&scope=projects', `/search?search=test&scope=users`],
+      [`https://gdk.test:3000/search?search=test`, `/search?search=test&scope=users`],
+      ['/groups/my-group/search', `/groups/my-group/search?scope=users`],
+      ['/groups/my-group/search?search=test', `/groups/my-group/search?search=test&scope=users`],
+    ])('transforms %s to %s', (input, expected) => {
+      expect(injectUsersScope(input)).toBe(expected);
     });
   });
 
@@ -389,66 +355,6 @@ describe('Global Search Store Utils', () => {
       expect(result).toBe(parentScope);
     });
   });
-  describe('skipBlobESCount', () => {
-    const SCOPE_BLOB = 'blobs';
-
-    let state;
-
-    beforeEach(() => {
-      state = {
-        query: {},
-        zoektAvailable: false,
-      };
-
-      window.gon = {
-        features: {
-          zoektMultimatchFrontend: false,
-        },
-      };
-    });
-
-    it('returns true when no group_id or project_id is present', () => {
-      expect(skipBlobESCount(state, SCOPE_BLOB)).toBe(true);
-    });
-
-    it('returns true when zoektMultimatchFrontend feature flag is off', () => {
-      state.query.group_id = '1';
-      state.zoektAvailable = true;
-
-      expect(skipBlobESCount(state, SCOPE_BLOB)).toBe(true);
-    });
-
-    it('returns true when zoekt is not available', () => {
-      state.query.group_id = '1';
-      window.gon.features.zoektMultimatchFrontend = true;
-
-      expect(skipBlobESCount(state, SCOPE_BLOB)).toBe(true);
-    });
-
-    it('returns true when scope is not blob', () => {
-      state.query.group_id = '1';
-      state.zoektAvailable = true;
-      window.gon.features.zoektMultimatchFrontend = true;
-
-      expect(skipBlobESCount(state, 'not_blob')).toBe(true);
-    });
-
-    it('returns false when all conditions are met', () => {
-      state.query.group_id = '1';
-      state.zoektAvailable = true;
-      window.gon.features.zoektMultimatchFrontend = true;
-
-      expect(skipBlobESCount(state, SCOPE_BLOB)).toBe(false);
-    });
-
-    it('returns false when using project_id instead of group_id', () => {
-      state.query.project_id = '1';
-      state.zoektAvailable = true;
-      window.gon.features.zoektMultimatchFrontend = true;
-
-      expect(skipBlobESCount(state, SCOPE_BLOB)).toBe(false);
-    });
-  });
 
   describe('buildDocumentTitle', () => {
     const SEARCH_WINDOW_TITLE = `Search`; // Make sure this matches your actual constant
@@ -491,4 +397,84 @@ describe('Global Search Store Utils', () => {
       expect(result).toBe(`test · ${SEARCH_WINDOW_TITLE} · GitLab`);
     });
   });
+
+  describe('modifySearchQuery', () => {
+    beforeEach(() => {
+      jest.clearAllMocks();
+    });
+
+    it('adds new query parameters to a URL without existing parameters', () => {
+      const result = modifySearchQuery('/search', { search: 'test' });
+
+      expect(result).toBe('/search?search=test');
+    });
+
+    it('adds new query parameters to a URL with existing parameters', () => {
+      const result = modifySearchQuery('/search?scope=projects', { search: 'test' });
+
+      expect(result).toBe('/search?scope=projects&search=test');
+    });
+
+    it('overrides existing query parameters with the same name', () => {
+      const result = modifySearchQuery('/search?search=old&scope=projects', { search: 'new' });
+
+      expect(result).toBe('/search?search=new&scope=projects');
+    });
+
+    it('handles absolute URLs correctly', () => {
+      const result = modifySearchQuery(`${TEST_HOST}/search`, { search: 'test' });
+
+      expect(result).toBe('/search?search=test');
+    });
+  });
+
+  describe('injectRegexSearch', () => {
+    describe('with objectOnly parameter', () => {
+      it('returns an empty object when regex is not enabled in localStorage', () => {
+        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(false));
+
+        const result = injectRegexSearch('/search', true);
+
+        expect(result).toEqual({});
+      });
+
+      it('returns the regex search object when regex is enabled in localStorage', () => {
+        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(true));
+
+        const result = injectRegexSearch('/search', true);
+        expect(result).toEqual({ regex: true });
+      });
+
+      it('returns an empty object when regex is not set in localStorage', () => {
+        localStorage.removeItem(LS_REGEX_HANDLE);
+
+        const result = injectRegexSearch('/search', true);
+
+        expect(result).toEqual({});
+      });
+    });
+
+    describe.each`
+      urlIn                                                            | urlOut
+      ${`${TEST_HOST}/search?search=test&group_id=123`}                | ${'/search?search=test&group_id=123'}
+      ${'/search?search=test&group_id=123'}                            | ${'/search?search=test&group_id=123'}
+      ${`${TEST_HOST}/search?search=test&project_id=123`}              | ${'/search?search=test&project_id=123'}
+      ${'/search?search=test&project_id=123'}                          | ${'/search?search=test&project_id=123'}
+      ${`${TEST_HOST}/search?search=test&project_id=123&group_id=123`} | ${'/search?search=test&project_id=123&group_id=123'}
+      ${'/search?search=test&project_id=123&group_id=123'}             | ${'/search?search=test&project_id=123&group_id=123'}
+    `('modifies urls and links', ({ urlIn, urlOut }) => {
+      it(`should add regex=true to ${urlIn}`, () => {
+        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(true));
+
+        const result = injectRegexSearch(urlIn);
+
+        expect(result).toEqual(`${urlOut}&regex=true`);
+      });
+
+      it(`should NOT add regex=true to ${urlIn}`, () => {
+        localStorage.setItem(LS_REGEX_HANDLE, JSON.stringify(false));
+        expect(injectRegexSearch(urlIn)).toEqual(urlOut);
+      });
+    });
+  });
 });
