@@ -5,8 +5,6 @@ import { mountExtended } from 'helpers/vue_test_utils_helper';
 import HelpCenter from '~/super_sidebar/components/help_center.vue';
 import { helpPagePath } from '~/helpers/help_page_helper';
 import { FORUM_URL, PROMO_URL, CONTRIBUTE_URL } from '~/constants';
-import { useLocalStorageSpy, useWithoutLocalStorage } from 'helpers/local_storage_helper';
-import { STORAGE_KEY } from '~/whats_new/utils/notification';
 import { mockTracking } from 'helpers/tracking_helper';
 import { sidebarData } from '../mock_data';
 
@@ -33,6 +31,7 @@ describe('HelpCenter component', () => {
       stubs: { GlEmoji },
       provide: {
         isSaas: false,
+        isIconOnly: false,
         ...provide,
       },
     });
@@ -116,18 +115,6 @@ describe('HelpCenter component', () => {
       ]);
     });
 
-    describe('when localStorage is disabled', () => {
-      useWithoutLocalStorage();
-
-      beforeEach(() => {
-        createWrapper();
-      });
-
-      it('renders component without errors', () => {
-        expect(findDropdown().exists()).toBe(true);
-      });
-    });
-
     describe('compare plans URL', () => {
       it('uses the compare_plans_url provided in sidebarData', () => {
         const customSidebarData = {
@@ -159,24 +146,6 @@ describe('HelpCenter component', () => {
       });
     });
 
-    describe('with matching version digest in local storage', () => {
-      useLocalStorageSpy();
-
-      beforeEach(() => {
-        window.localStorage.setItem(STORAGE_KEY, 1);
-        createWrapper(sidebarData);
-      });
-
-      it('renders menu items', () => {
-        expect(findDropdownGroup(0).props('group').items).toEqual(getDefaultHelpItems());
-
-        expect(findDropdownGroup(1).props('group').items).toEqual([
-          expect.objectContaining({ text: HelpCenter.i18n.shortcuts }),
-          expect.objectContaining({ text: HelpCenter.i18n.whatsnew }),
-        ]);
-      });
-    });
-
     describe('with GitLab version check feature enabled', () => {
       beforeEach(() => {
         createWrapper({
@@ -283,7 +252,13 @@ describe('HelpCenter component', () => {
 
       it("shows the What's new slideout", () => {
         expect(toggleWhatsNewDrawer).toHaveBeenCalledWith(
-          sidebarData.whats_new_version_digest,
+          {
+            versionDigest: sidebarData.whats_new_version_digest,
+            initialReadArticles: sidebarData.whats_new_read_articles,
+            markAsReadPath: sidebarData.whats_new_mark_as_read_path,
+            mostRecentReleaseItemsCount: sidebarData.whats_new_most_recent_release_items_count,
+          },
+          expect.any(Function),
           expect.any(Function),
         );
       });
@@ -325,8 +300,6 @@ describe('HelpCenter component', () => {
       });
 
       describe('when setting is enabled', () => {
-        useLocalStorageSpy();
-
         beforeEach(() => {
           createWrapper({
             ...sidebarData,
@@ -347,19 +320,22 @@ describe('HelpCenter component', () => {
             expect(findNotificationCount().exists()).toBe(true);
           });
         });
+      });
 
-        describe('with matching version digest in local storage', () => {
-          beforeEach(() => {
-            window.localStorage.setItem(STORAGE_KEY, 1);
-            createWrapper({
-              ...sidebarData,
-              display_whats_new: true,
-            });
-          });
+      describe('with all articles read', () => {
+        beforeEach(() => {
+          createWrapper({ ...sidebarData, whats_new_read_articles: [1, 2] });
+        });
 
-          it('does not render notification count', () => {
-            expect(findNotificationCount().exists()).toBe(false);
-          });
+        it('renders menu items, does not render notification count', () => {
+          expect(findNotificationCount().exists()).toBe(false);
+
+          expect(findDropdownGroup(0).props('group').items).toEqual(getDefaultHelpItems());
+
+          expect(findDropdownGroup(1).props('group').items).toEqual([
+            expect.objectContaining({ text: HelpCenter.i18n.shortcuts }),
+            expect.objectContaining({ text: HelpCenter.i18n.whatsnew }),
+          ]);
         });
       });
     });
