@@ -50,6 +50,9 @@ describe('OrganizationSwitcher', () => {
 
     wrapper = mountExtended(OrganizationSwitcher, {
       apolloProvider: mockApollo,
+      provide: {
+        projectStudioEnabled: false,
+      },
     });
   };
 
