@@ -4,9 +4,11 @@ import { nextTick } from 'vue';
 import axios from '~/lib/utils/axios_utils';
 import { mountExtended } from 'helpers/vue_test_utils_helper';
 import { stubComponent } from 'helpers/stub_component';
+import { useLocalStorageSpy } from 'helpers/local_storage_helper';
 import UserMenu from '~/super_sidebar/components/user_menu.vue';
 import UserMenuProfileItem from '~/super_sidebar/components/user_menu_profile_item.vue';
 import SetStatusModal from '~/set_status_modal/set_status_modal_wrapper.vue';
+import DapWelcomeModal from '~/dap_welcome_modal/dap_welcome_modal.vue';
 import { mockTracking } from 'helpers/tracking_helper';
 import { visitUrl } from '~/lib/utils/url_utility';
 import * as Sentry from '~/sentry/sentry_browser_wrapper';
@@ -26,6 +28,7 @@ describe('UserMenu component', () => {
   const GlEmoji = { template: '<img/>' };
   const findDropdown = () => wrapper.findComponent(GlDisclosureDropdown);
   const findSetStatusModal = () => wrapper.findComponent(SetStatusModal);
+  const findDapWelcomeModal = () => wrapper.findComponent(DapWelcomeModal);
   const showDropdown = () => findDropdown().vm.$emit('shown');
   const findStopImpersonationButton = () => wrapper.findByTestId('stop-impersonation-btn');
 
@@ -42,6 +45,7 @@ describe('UserMenu component', () => {
       stubs: {
         GlEmoji,
         GlAvatar: true,
+        GlIcon: true,
         SetStatusModal: stubComponent(SetStatusModal),
         ...stubs,
       },
@@ -283,46 +287,6 @@ describe('UserMenu component', () => {
     });
   });
 
-  describe('Start Ultimate trial item', () => {
-    let item;
-
-    const setItem = ({ has_start_trial } = {}) => {
-      createWrapper({ trial: { has_start_trial, url: '' } });
-      item = wrapper.findByTestId('start-trial-item');
-    };
-
-    describe('When Ultimate trial is not suggested for the user', () => {
-      it('does not render the start trial menu item', () => {
-        setItem();
-        expect(item.exists()).toBe(false);
-      });
-    });
-
-    describe('When Ultimate trial can be suggested for the user', () => {
-      it('does render the start trial menu item', () => {
-        setItem({ has_start_trial: true });
-        expect(item.exists()).toBe(true);
-      });
-    });
-
-    it('has Snowplow tracking attributes', () => {
-      setItem({ has_start_trial: true });
-      expect(item.find('a').attributes()).toMatchObject({
-        'data-track-property': 'nav_user_menu',
-        'data-track-action': 'click_link',
-        'data-track-label': 'start_trial',
-      });
-    });
-
-    describe('When trial info is not provided', () => {
-      it('does not render the start trial menu item', () => {
-        createWrapper();
-
-        expect(wrapper.findByTestId('start-trial-item').exists()).toBe(false);
-      });
-    });
-  });
-
   describe('Buy compute minutes item', () => {
     /** @type {import('@vue/test-utils').Wrapper} */
     let item;
@@ -525,6 +489,18 @@ describe('UserMenu component', () => {
     });
   });
 
+  describe('mobile user counts', () => {
+    it('do not render when Project Studio is disabled', () => {
+      createWrapper();
+      expect(wrapper.findByTestId('user-counts-item').exists()).toBe(false);
+    });
+
+    it('should render with mobile-only CSS', () => {
+      createWrapper({}, {}, { projectStudioEnabled: true });
+      expect(wrapper.findByTestId('user-counts-item').classes()).toContain('md:gl-hidden');
+    });
+  });
+
   describe('Preferences item', () => {
     let item;
 
@@ -549,6 +525,39 @@ describe('UserMenu component', () => {
     });
   });
 
+  describe('DAP welcome modal', () => {
+    useLocalStorageSpy();
+
+    it.each`
+      description                          | showDapWelcomeModal | modalVisibility
+      ${'shows DAP welcome modal'}         | ${'true'}           | ${true}
+      ${'does not show DAP welcome modal'} | ${'false'}          | ${false}
+    `(
+      '$description when showDapWelcomeModal localStorageKey is set to $showDapWelcomeModal',
+      async ({ showDapWelcomeModal, modalVisibility }) => {
+        localStorage.setItem('showDapWelcomeModal', showDapWelcomeModal);
+
+        createWrapper();
+
+        await nextTick();
+
+        expect(findDapWelcomeModal().exists()).toBe(modalVisibility);
+      },
+    );
+
+    it('closing DAP welcome modal causes showDapWelcomeModal localStorage key set to `false`', async () => {
+      localStorage.setItem('showDapWelcomeModal', 'true');
+
+      createWrapper();
+
+      await nextTick();
+
+      findDapWelcomeModal().vm.$emit('close');
+
+      expect(localStorage.setItem).toHaveBeenCalledWith('showDapWelcomeModal', 'false');
+    });
+  });
+
   describe('GitLab Next item', () => {
     describe('on gitlab.com', () => {
       let item;
@@ -584,18 +593,32 @@ describe('UserMenu component', () => {
     const findAdminLinkItem = () => wrapper.findByTestId('admin-link');
 
     it.each`
-      projectStudioEnabled | isAdmin  | isRendered
-      ${false}             | ${false} | ${false}
-      ${false}             | ${true}  | ${false}
-      ${true}              | ${false} | ${false}
-      ${true}              | ${true}  | ${true}
+      projectStudioEnabled | isAdmin  | adminModeFeatureEnabled | adminModeActive | isRendered
+      ${false}             | ${false} | ${false}                | ${false}        | ${false}
+      ${false}             | ${false} | ${false}                | ${true}         | ${false}
+      ${false}             | ${false} | ${true}                 | ${false}        | ${false}
+      ${false}             | ${false} | ${true}                 | ${true}         | ${false}
+      ${false}             | ${true}  | ${false}                | ${false}        | ${false}
+      ${false}             | ${true}  | ${false}                | ${true}         | ${false}
+      ${false}             | ${true}  | ${true}                 | ${false}        | ${false}
+      ${false}             | ${true}  | ${true}                 | ${true}         | ${false}
+      ${true}              | ${false} | ${false}                | ${false}        | ${false}
+      ${true}              | ${false} | ${false}                | ${true}         | ${false}
+      ${true}              | ${false} | ${true}                 | ${false}        | ${false}
+      ${true}              | ${false} | ${true}                 | ${true}         | ${false}
+      ${true}              | ${true}  | ${false}                | ${false}        | ${true}
+      ${true}              | ${true}  | ${false}                | ${true}         | ${true}
+      ${true}              | ${true}  | ${true}                 | ${false}        | ${false}
+      ${true}              | ${true}  | ${true}                 | ${true}         | ${true}
     `(
-      'admin link item rendered is $isRendered when project studio is $projectStudioEnabled and isAdmin is $isAdmin',
-      ({ projectStudioEnabled, isAdmin, isRendered }) => {
+      'admin link item rendered is $isRendered when project studio is $projectStudioEnabled, isAdmin is $isAdmin, adminModeFeatureEnabled is $adminModeFeatureEnabled, and adminModeActive is $adminModeActive',
+      ({ projectStudioEnabled, isAdmin, adminModeFeatureEnabled, adminModeActive, isRendered }) => {
         createWrapper(
           {
             admin_mode: {
               user_is_admin: isAdmin,
+              admin_mode_feature_enabled: adminModeFeatureEnabled,
+              admin_mode_active: adminModeActive,
             },
           },
           {},
