@@ -22,7 +22,7 @@ const itCorrectlyFormatsWithActions = (formattedGroup, mockGroup) => {
     accessLevel: {
       integerValue: 50,
     },
-    availableActions: ['edit', 'restore', 'leave', 'delete-immediately'],
+    availableActions: ['copy-id', 'edit', 'restore', 'leave', 'delete-immediately'],
     children: [],
     childrenLoading: false,
     hasChildren: false,
@@ -40,13 +40,13 @@ const itCorrectlyFormatsWithoutActions = (formattedGroup, mockGroup) => {
     accessLevel: {
       integerValue: 0,
     },
-    availableActions: [],
+    availableActions: ['copy-id'],
   });
 };
 
 describe('formatGraphQLGroup', () => {
   it('correctly formats the group with edit, delete, and leave permissions', () => {
-    window.gon = { relative_url_root: '/gitlab' };
+    window.gon = { relative_url_root: '/gitlab', allow_immediate_namespaces_deletion: true };
     const [mockGroup] = organizationGroups;
     const formattedGroup = formatGraphQLGroup(mockGroup, (group) => ({
       customProperty: group.fullName,
@@ -65,7 +65,7 @@ describe('formatGraphQLGroup', () => {
 
 describe('formatGraphQLGroups', () => {
   it('correctly formats the groups with edit, delete, and leave permissions', () => {
-    window.gon = { relative_url_root: '/gitlab' };
+    window.gon = { relative_url_root: '/gitlab', allow_immediate_namespaces_deletion: true };
     const [firstMockGroup] = organizationGroups;
     const formattedGroups = formatGraphQLGroups(organizationGroups, (group) => ({
       customProperty: group.fullName,
