@@ -1,4 +1,4 @@
-import adminGroupsGraphQlResponse from 'test_fixtures/graphql/admin/groups.query.graphql.json';
+import adminGroupsGraphQlResponse from 'test_fixtures/graphql/admin/admin_groups.query.graphql.json';
 import { formatGraphQLGroups } from '~/vue_shared/components/groups_list/formatter';
 
 const {
