@@ -13,20 +13,16 @@ describe('WorkItemBreadcrumb', () => {
     $route = {},
     listPath = '/epics',
     isGroup = true,
-    workItemsAlpha = false,
     workItemPlanningView = false,
     workItemViewForIssues = false,
-    workItemsProjectIssuesList = false,
     props = {},
   } = {}) => {
     wrapper = shallowMount(WorkItemBreadcrumb, {
       provide: {
         workItemType,
         glFeatures: {
-          workItemsAlpha,
           workItemPlanningView,
           workItemViewForIssues,
-          workItemsProjectIssuesList,
         },
         listPath,
         isGroup,
@@ -100,7 +96,6 @@ describe('WorkItemBreadcrumb', () => {
           isGroup: false,
           listPath: '/issues',
           workItemViewForIssues: true,
-          workItemsProjectIssuesList: true,
         });
 
         expect(findBreadcrumb().props('items')).toEqual([
@@ -113,39 +108,6 @@ describe('WorkItemBreadcrumb', () => {
           },
         ]);
       });
-
-      it('renders root breadcrumb with href if user turned work item view on but not on work item project issues list', () => {
-        createComponent({
-          isGroup: false,
-          listPath: '/issues',
-          workItemViewForIssues: true,
-          workItemsProjectIssuesList: false,
-        });
-
-        expect(findBreadcrumb().props('items')).toEqual([
-          {
-            text: 'Issues',
-            href: '/issues',
-          },
-        ]);
-      });
-
-      it('renders root breadcrumb with href if not on work item project issues list regardless of workItemsAlpha flag', () => {
-        createComponent({
-          isGroup: false,
-          listPath: '/issues',
-          workItemsAlpha: true,
-          workItemViewForIssues: true,
-          workItemsProjectIssuesList: false,
-        });
-
-        expect(findBreadcrumb().props('items')).toEqual([
-          {
-            text: 'Issues',
-            href: '/issues',
-          },
-        ]);
-      });
     });
   });
 
