@@ -88,8 +88,12 @@ RSpec.describe ApplicationSettingsHelper, feature_category: :shared do
           group_archive_unarchive_api_limit
           group_invited_groups_api_limit
           project_invited_groups_api_limit
+          project_members_api_limit
           create_organization_api_limit
           top_level_group_creation_enabled
+          runner_jobs_request_api_limit
+          runner_jobs_patch_trace_api_limit
+          runner_jobs_endpoints_api_limit
         ])
     end
 
@@ -101,6 +105,7 @@ RSpec.describe ApplicationSettingsHelper, feature_category: :shared do
         global_search_merge_requests_enabled
         global_search_block_anonymous_searches_enabled
         anonymous_searches_allowed
+        default_search_scope
       ]
       expect(helper.visible_attributes).to include(*expected_fields)
     end
