@@ -39,6 +39,7 @@ RSpec.describe Ci::PipelineEditorHelper, feature_category: :pipeline_composition
         "lint-help-page-path" => help_page_path('ci/yaml/lint.md', anchor: 'check-cicd-syntax'),
         "needs-help-page-path" => help_page_path('ci/yaml/_index.md', anchor: 'needs'),
         "new-merge-request-path" => '/mock/project/-/merge_requests/new',
+        "new-pipeline-path" => new_project_pipeline_path(project),
         "pipeline-page-path" => project_pipelines_path(project),
         "project-path" => project.path,
         "project-full-path" => project.full_path,
@@ -55,6 +56,11 @@ RSpec.describe Ci::PipelineEditorHelper, feature_category: :pipeline_composition
         .to receive(:namespace_project_new_merge_request_path)
         .and_return('/mock/project/-/merge_requests/new')
 
+      allow(helper)
+        .to receive(:can?)
+        .with(user, :create_pipeline, project)
+        .and_return(true)
+
       allow(helper)
         .to receive(:image_path)
         .with('illustrations/empty-state/empty-pipeline-md.svg')
