@@ -9,7 +9,7 @@ RSpec.describe Gitlab::BitbucketServerImport::UserFinder, :clean_gitlab_redis_sh
   let_it_be_with_reload(:project) do
     create(
       :project, :repository, :bitbucket_server_import, :in_group,
-      :import_user_mapping_enabled, :user_mapping_to_personal_namespace_owner_enabled
+      :import_user_mapping_enabled
     )
   end
 
@@ -46,19 +46,6 @@ RSpec.describe Gitlab::BitbucketServerImport::UserFinder, :clean_gitlab_redis_sh
 
         expect(author_id).to eq(user_namespace.owner_id)
       end
-
-      context 'when user_mapping_to_personal_namespace_owner is disabled' do
-        before do
-          allow(project.import_data).to receive(:user_mapping_to_personal_namespace_owner_enabled?)
-            .and_return(false)
-        end
-
-        it 'returns the mapped user' do
-          expect(
-            user_finder.author_id(user_representation)
-          ).to eq(source_user.mapped_user.id)
-        end
-      end
     end
   end
 
@@ -93,27 +80,6 @@ RSpec.describe Gitlab::BitbucketServerImport::UserFinder, :clean_gitlab_redis_sh
 
         expect(user_id).to eq(user_namespace.owner_id)
       end
-
-      context 'when user_mapping_to_personal_namespace_owner is disabled' do
-        before do
-          allow(project.import_data).to receive(:user_mapping_to_personal_namespace_owner_enabled?)
-            .and_return(false)
-        end
-
-        it 'takes a user data hash and finds the mapped user ID' do
-          user_id = user_finder.uid(user_representation)
-
-          expect(user_id).to eq(source_user.mapped_user.id)
-        end
-
-        it 'returns nil when username is nil' do
-          user_representation[:username] = nil
-
-          user_id = user_finder.uid(user_representation)
-
-          expect(user_id).to be_nil
-        end
-      end
     end
   end
 
