@@ -8,16 +8,16 @@ RSpec.describe Gitlab::Ci::Config, feature_category: :pipeline_composition do
 
   let_it_be(:user) { create(:user) }
 
+  let(:config) do
+    described_class.new(yml, project: nil, pipeline: nil, sha: nil, user: nil)
+  end
+
   before do
     allow_next_instance_of(Gitlab::Ci::Config::External::Context) do |instance|
       allow(instance).to receive(:check_execution_time!)
     end
   end
 
-  let(:config) do
-    described_class.new(yml, project: nil, pipeline: nil, sha: nil, user: nil)
-  end
-
   context 'when config is valid' do
     let(:yml) do
       <<-EOS
@@ -35,8 +35,10 @@ RSpec.describe Gitlab::Ci::Config, feature_category: :pipeline_composition do
         hash = {
           image: 'image:1.0',
           rspec: {
-            script: ['gem install rspec',
-                     'rspec']
+            script: [
+              'gem install rspec',
+              'rspec'
+            ]
           }
         }
 
@@ -209,8 +211,8 @@ RSpec.describe Gitlab::Ci::Config, feature_category: :pipeline_composition do
     it 'returns only components included with `include:component`' do
       expect(config.metadata[:includes].size).to eq(3)
       expect(included_components).to contain_exactly(
-        { project: project1, sha: project1.commit.sha, name: 'dast' },
-        { project: project2, sha: project2.commit.sha, name: 'template' }
+        { project: project1, sha: project1.commit.sha, name: 'dast', version: nil, reference: '1.0.0' },
+        { project: project2, sha: project2.commit.sha, name: 'template', version: nil, reference: '1.0.0' }
       )
     end
 
@@ -226,7 +228,7 @@ RSpec.describe Gitlab::Ci::Config, feature_category: :pipeline_composition do
       it 'returns only unique components' do
         expect(config.metadata[:includes].size).to eq(2)
         expect(included_components).to contain_exactly(
-          { project: project1, sha: project1.commit.sha, name: 'dast' }
+          { project: project1, sha: project1.commit.sha, name: 'dast', version: nil, reference: '1.0.0' }
         )
       end
     end
