@@ -17,7 +17,8 @@ RSpec.describe Gitlab::Database::GitlabSchema, feature_category: :database do
         .values
 
       database_connections.permutation(2) do |db, other_db|
-        gitlab_schemas = db.gitlab_schemas - [:gitlab_shared, :gitlab_internal]
+        gitlab_schemas = db.gitlab_schemas -
+          [:gitlab_shared, :gitlab_internal, :gitlab_shared_org, :gitlab_shared_cell_local]
 
         expect(other_db.lock_gitlab_schemas).to include(*gitlab_schemas),
           "Expected `#{other_db.name}` lock_gitlab_schemas to include `#{db.name}` gitlab_schemas:"
@@ -42,6 +43,8 @@ RSpec.describe Gitlab::Database::GitlabSchema, feature_category: :database do
       '_test_gitlab_main_org_table'                  | :gitlab_main_org
       '_test_gitlab_pm_table'                        | :gitlab_pm
       '_test_gitlab_sec_table'                       | :gitlab_sec
+      '_test_gitlab_shared_org_table'                | :gitlab_shared_org
+      '_test_gitlab_shared_cell_local_table'         | :gitlab_shared_cell_local
       '_test_my_table'                               | :gitlab_shared
       'pg_attribute'                                 | :gitlab_internal
     end
@@ -82,7 +85,8 @@ RSpec.describe Gitlab::Database::GitlabSchema, feature_category: :database do
                 "Missing table/view(s) #{missing_data_sources.to_a} not found in " \
                 "#{described_class}.views_and_tables_to_schema. " \
                 "Any new tables or views must be added to the database dictionary. " \
-                "More info: https://docs.gitlab.com/ee/development/database/database_dictionary.html"
+                "More info: https://docs.gitlab.com/ee/development/database/database_dictionary.html " \
+                "Use `bin/rake gitlab:db:dictionary:generate` to create a new dictionary file."
             end
 
             it 'non-existing data sources are removed' do
@@ -180,7 +184,8 @@ RSpec.describe Gitlab::Database::GitlabSchema, feature_category: :database do
         expect { subject }.to raise_error(
           Gitlab::Database::GitlabSchema::UnknownSchemaError,
           "Could not find gitlab schema for table #{name}: " \
-          "Any new or deleted tables must be added to the database dictionary " \
+          "Any new or deleted tables must be added to the database dictionary. " \
+          "Use `bin/rake gitlab:db:dictionary:generate` to create a new dictionary file. " \
           "See https://docs.gitlab.com/ee/development/database/database_dictionary.html"
         )
       end
