@@ -32,7 +32,11 @@ RSpec.describe Gitlab::Database::LoadBalancing::Host, feature_category: :databas
 
   describe '#connection' do
     it 'returns a connection from the pool' do
-      expect(host.pool).to receive(:connection)
+      if Gitlab.next_rails?
+        expect(host.pool).to receive(:lease_connection)
+      else
+        expect(host.pool).to receive(:connection)
+      end
 
       host.connection
     end
@@ -209,6 +213,13 @@ RSpec.describe Gitlab::Database::LoadBalancing::Host, feature_category: :databas
 
         expect(host).not_to be_online
       end
+
+      it 'returns false when the pool is discarded' do
+        pool = double(:pool, discarded?: true)
+        allow(host).to receive(:pool).and_return(pool)
+
+        expect(host).not_to be_online
+      end
     end
   end
 
@@ -248,7 +259,7 @@ RSpec.describe Gitlab::Database::LoadBalancing::Host, feature_category: :databas
       # Clear the cache for latest_lsn_query
       host.refresh_status
 
-      # Should recieve LATEST_LSN_WITHOUT_LOGICAL_QUERY since we received 'f'
+      # Should receive LATEST_LSN_WITHOUT_LOGICAL_QUERY since we received 'f'
       # after clearing the cache
       expect(host)
         .to receive(:query_and_release)
