@@ -72,8 +72,6 @@ RSpec.describe Gitlab::GithubImport::Settings, feature_category: :importers do
         .to be true
       expect(project.import_data.data['pagination_limit'])
         .to eq(50)
-      expect(project.import_data.data['user_mapping_to_personal_namespace_owner_enabled'])
-        .to be true
     end
   end
 
@@ -115,19 +113,10 @@ RSpec.describe Gitlab::GithubImport::Settings, feature_category: :importers do
       it { is_expected.to be(expected_enabled) }
     end
 
-    shared_examples 'when :gitea_user_mapping is disabled' do |expected_enabled:|
-      before do
-        Feature.disable(:gitea_user_mapping)
-      end
-
-      it { is_expected.to be(expected_enabled) }
-    end
-
     context 'when the project is a GitHub import' do
       it { is_expected.to be(true) }
 
       it_behaves_like 'when :github_user_mapping is disabled', expected_enabled: false
-      it_behaves_like 'when :gitea_user_mapping is disabled', expected_enabled: true
     end
 
     context 'when the project is a Gitea import' do
@@ -137,7 +126,6 @@ RSpec.describe Gitlab::GithubImport::Settings, feature_category: :importers do
 
       it { is_expected.to be(true) }
 
-      it_behaves_like 'when :gitea_user_mapping is disabled', expected_enabled: false
       it_behaves_like 'when :github_user_mapping is disabled', expected_enabled: true
     end
 
@@ -148,7 +136,6 @@ RSpec.describe Gitlab::GithubImport::Settings, feature_category: :importers do
 
       it { is_expected.to be(false) }
 
-      it_behaves_like 'when :gitea_user_mapping is disabled', expected_enabled: false
       it_behaves_like 'when :github_user_mapping is disabled', expected_enabled: false
     end
 
@@ -159,97 +146,33 @@ RSpec.describe Gitlab::GithubImport::Settings, feature_category: :importers do
 
       it { is_expected.to be(false) }
 
-      it_behaves_like 'when :gitea_user_mapping is disabled', expected_enabled: false
       it_behaves_like 'when :github_user_mapping is disabled', expected_enabled: false
     end
   end
 
   describe '#map_to_personal_namespace_owner?' do
     let_it_be(:group) { create(:group) }
+    let_it_be(:user) { create(:user, :with_namespace) }
 
     subject do
       settings.write(data_input)
       settings.map_to_personal_namespace_owner?
     end
 
-    shared_examples 'when :github_user_mapping is disabled' do |expected_enabled:|
+    context 'when project is imported into a personal namespace' do
       before do
-        Feature.disable(:github_user_mapping)
+        project.update!(namespace: user.namespace)
       end
 
-      it { is_expected.to be(expected_enabled) }
+      it { is_expected.to be(true) }
     end
 
-    shared_examples 'when :gitea_user_mapping is disabled' do |expected_enabled:|
-      before do
-        Feature.disable(:gitea_user_mapping)
-      end
-
-      it { is_expected.to be(expected_enabled) }
-    end
-
-    shared_examples 'disabled when project is imported into a group' do
+    context 'when project is imported into a group' do
       before_all do
         project.update!(namespace: group)
       end
 
       it { is_expected.to be(false) }
     end
-
-    before do
-      project.build_or_assign_import_data(credentials: { user: 'token' })
-    end
-
-    context 'when the project is a GitHub import' do
-      it { is_expected.to be(true) }
-
-      it_behaves_like 'when :github_user_mapping is disabled', expected_enabled: false
-      it_behaves_like 'when :gitea_user_mapping is disabled', expected_enabled: true
-      it_behaves_like 'disabled when project is imported into a group'
-    end
-
-    context 'when the project is a Gitea import' do
-      before do
-        project.update!(import_type: ::Import::SOURCE_GITEA.to_s)
-      end
-
-      it { is_expected.to be(true) }
-
-      it_behaves_like 'when :gitea_user_mapping is disabled', expected_enabled: false
-      it_behaves_like 'when :github_user_mapping is disabled', expected_enabled: true
-      it_behaves_like 'disabled when project is imported into a group'
-    end
-
-    context 'when the project does not have an import_type' do
-      before do
-        project.update!(import_type: nil)
-      end
-
-      it { is_expected.to be(false) }
-
-      it_behaves_like 'when :gitea_user_mapping is disabled', expected_enabled: false
-      it_behaves_like 'when :github_user_mapping is disabled', expected_enabled: false
-      it_behaves_like 'disabled when project is imported into a group'
-    end
-
-    context 'when the project has an import_type without a user mapping flag' do
-      before do
-        project.update!(import_type: ::Import::SOURCE_BITBUCKET.to_s)
-      end
-
-      it { is_expected.to be(false) }
-
-      it_behaves_like 'when :gitea_user_mapping is disabled', expected_enabled: false
-      it_behaves_like 'when :github_user_mapping is disabled', expected_enabled: false
-      it_behaves_like 'disabled when project is imported into a group'
-    end
-
-    context 'when the feature flag is disabled' do
-      before do
-        stub_feature_flags(user_mapping_to_personal_namespace_owner: false)
-      end
-
-      it { is_expected.to be(false) }
-    end
   end
 end
